@@ -6,18 +6,16 @@ class Checkbox(BoolElement):
 
     def __init__(self,
                  text: str = '',
+                 *,
                  value: bool = False,
                  on_change: Callable = None,
-                 design: str = '',
-                 classes: str = '',
                  ):
         """Checkbox Element
 
-        :param text: the label to display beside the checkbox
-        :param value: set to True if initally it should be checked; default is False
-        :param design: Quasar props to alter the appearance (see `their reference <https://quasar.dev/vue-components/checkbox>`_)
+        :param text: the label to display next to the checkbox
+        :param value: set to `True` if it should be checked initally; default is `False`
         :param on_change: callback to execute when value changes
         """
         view = jp.QCheckbox(text=text, input=self.handle_change)
 
-        super().__init__(view, value, on_change, design=design, classes=classes)
+        super().__init__(view, value=value, on_change=on_change)
