@@ -6,16 +6,14 @@ class ChoiceElement(ValueElement):
 
     def __init__(self,
                  view: jp.HTMLBaseComponent,
-                 value: Any,
                  options: Union[List, Dict],
-                 on_change: Callable,
-                 design: str,
-                 classes: str,
-                 ):
+                 *,
+                 value: Any,
+                 on_change: Callable):
 
         if isinstance(options, list):
             view.options = [{'label': option, 'value': option} for option in options]
         else:
             view.options = [{'label': value, 'value': key} for key, value in options.items()]
 
-        super().__init__(view, value, on_change, design=design, classes=classes)
+        super().__init__(view, value=value, on_change=on_change)
