@@ -7,4 +7,4 @@ class Column(Group):
 
         view = jp.QDiv(classes='column items-start', style='gap: 1em', delete_flag=False)
 
-        super().__init__(view, '')
+        super().__init__(view)
