@@ -3,16 +3,18 @@ from .element import Element
 
 class Html(Element):
 
-    def __init__(self, content: str = '', design='', classes: str = ''):
-        """Html Element
+    def __init__(self,
+                 content: str = '',
+                 ):
+        """HTML Element
 
-        Renders arbitrary html onto the page. `Tailwind <https://tailwindcss.com/>`_ can be used for styling.
+        Renders arbitrary HTML onto the page. `Tailwind <https://tailwindcss.com/>`_ can be used for styling.
 
-        :param content: the html code to be displayed
+        :param content: the HTML code to be displayed
         """
 
         view = jp.QDiv()
-        super().__init__(view, design=design, classes=classes)
+        super().__init__(view)
         self.content = content
 
     @property
