@@ -4,15 +4,17 @@ import re
 
 class Markdown(Html):
 
-    def __init__(self, content: str = '', classes: str = ''):
+    def __init__(self,
+                 content: str = '',
+                 ):
         """Markdown Element
 
         Renders markdown onto the page.
 
-        :param content: the markdown to be displayed
+        :param content: the markdown content to be displayed
         """
 
-        super().__init__(content, classes=classes)
+        super().__init__(content)
 
     def set_content(self, content: str):
 
