@@ -5,12 +5,16 @@ from .element import Element
 
 class Plot(Element):
 
-    def __init__(self, close: bool = True, **kwargs):
+    def __init__(self,
+                 *,
+                 close: bool = True,
+                 **kwargs,
+                 ):
         """Plot Context
 
         Create a context to configure a `Matplotlib <https://matplotlib.org/>`_ plot.
 
-        :param close: whether the figure should be closed after exiting the context; set to False if you want to update it later, default is True
+        :param close: whether the figure should be closed after exiting the context; set to `False` if you want to update it later, default is `True`
         :param kwargs: arguments like `figsize` which should be passed to `pyplot.figure <https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.figure.html>`_
         """
 
@@ -20,7 +24,7 @@ class Plot(Element):
         view = jp.Matplotlib()
         view.set_figure(self.fig)
 
-        super().__init__(view, '')
+        super().__init__(view)
 
     def __enter__(self):
 
