@@ -6,19 +6,17 @@ class Radio(ChoiceElement):
 
     def __init__(self,
                  options: Union[List, Dict],
+                 *,
                  value: any = None,
                  on_change: Callable = None,
-                 design: str = '',
-                 classes: str = ''
                  ):
         """Radio Selection Element
 
-        :param options: a list or dict specifying the options
+        :param options: a list ['value1', ...] or dictionary `{'value1':'label1', ...}` specifying the options
         :param value: the inital value
-        :param on_change: callback when selection changes
-        :param design: Quasar props to alter the appearance (see `their reference <https://quasar.dev/vue-components/radio>`_)
+        :param on_change: callback to execute when selection changes
         """
 
         view = jp.QOptionGroup(options=options, input=self.handle_change)
 
-        super().__init__(view, value, options, on_change, design=design, classes=classes)
+        super().__init__(view, options, value=value, on_change=on_change)
