@@ -8,20 +8,18 @@ class Slider(FloatElement):
                  *,
                  min: float,
                  max: float,
-                 value: float = None,
                  step: float = 1,
+                 value: float = None,
                  on_change: Callable = None,
-                 design: str = '',
-                 classes: str = '',
                  ):
         """Slider Element
 
         :param min: lower bound of the slider
         :param max: upper bound of the slider
+        :param step: step size
         :param value: inital value to set position of the slider
-        :param design: Quasar props to alter the appearance (see `their reference <https://quasar.dev/vue-components/slider>`_)
         :param on_change: callback which is invoked when the user releases the slider
         """
         view = jp.QSlider(min=min, max=max, step=step, change=self.handle_change)
 
-        super().__init__(view, value, None, on_change, design=design, classes=classes)
+        super().__init__(view, value=value, on_change=on_change)
