@@ -1,10 +1,16 @@
 class Ui:
 
+    from .run import run, config  # NOTE: before justpy
+
     from .elements.button import Button as button
     from .elements.checkbox import Checkbox as checkbox
+    from .elements.custom_example import CustomExample as custom_example
     from .elements.icon import Icon as icon
     from .elements.input import Input as input
+    from .elements.joystick import Joystick as joystick
     from .elements.label import Label as label
+    from .elements.image import Image as image
+    from .elements.svg import Svg as svg
     from .elements.html import Html as html
     from .elements.markdown import Markdown as markdown
     from .elements.link import Link as link
@@ -14,6 +20,7 @@ class Ui:
     from .elements.slider import Slider as slider
     from .elements.switch import Switch as switch
     from .elements.toggle import Toggle as toggle
+    from .elements.upload import Upload as upload
 
     from .elements.plot import Plot as plot
     from .elements.line_plot import LinePlot as line_plot
@@ -23,3 +30,5 @@ class Ui:
     from .elements.card import Card as card
 
     from .timer import Timer as timer
+
+    from .lifecycle import startup_tasks, on_startup, shutdown_tasks, on_shutdown
