@@ -11,15 +11,15 @@ class EventArguments:
 def provide_arguments(func, *keys):
     def inner_function(sender, event):
         try:
-            func()
+            return func()
         except TypeError:
-            func(EventArguments(sender, **{key: event[key] for key in keys}))
+            return func(EventArguments(sender, **{key: event[key] for key in keys}))
     return inner_function
 
 def handle_exceptions(func):
     def inner_function(*args, **kwargs):
         try:
-            func(*args, **kwargs)
+            return func(*args, **kwargs)
         except Exception:
             traceback.print_exc()
     return inner_function
